@@ -14,7 +14,10 @@ function(data, annot, do.mapping=FALSE, mapping, hg, verbose=FALSE) {
 	}
 	###########
 	ggi.gl <- cbind(sig.ggi[ ,c("probe", "EntrezGene.ID")], "coefficient"=ifelse(sig.ggi[ ,"grade"] == 1, -1, 1))
-	res <- sig.score(x=ggi.gl, data=data, annot=annot, do.mapping=do.mapping, mapping=mapping, signed=TRUE, verbose=verbose)$score
+	tt <- sig.score(x=ggi.gl, data=data, annot=annot, do.mapping=do.mapping, mapping=mapping, signed=TRUE, verbose=verbose)
+	myprobe <- tt$probe
+	mymapping <- tt$mapping
+	res <- tt$score
 		
 	if(!missing(hg)) {
 		if(length(hg) != nrow(data)) { stop("hg must have the same length nrow(data)!") }
@@ -22,11 +25,11 @@ function(data, annot, do.mapping=FALSE, mapping, hg, verbose=FALSE) {
 		mhg3 <- mean(res[hg == 3], na.rm=TRUE)
 		mm <- mhg1 + (mhg3 -  mhg1) / 2
 		res.scaled <- ((res - mm) / (mhg3 - mhg1)) * 2
-		res <- list("score"=res.scaled, "risk"=ifelse(res.scaled >= 0, 1, 0))	
+		res <- list("score"=res.scaled, "risk"=ifelse(res.scaled >= 0, 1, 0), "mapping"=mymapping, "probe"=myprobe)	
 	} else {
 		riskt <- rep(NA, length(res))
 		names(riskt) <- names(res)
-		res <- list("score"=res, "risk"=riskt)
+		res <- list("score"=res, "risk"=riskt, "mapping"=mymapping, "probe"=myprobe)
 	}
 	
 	return (res)
